@@ -19,9 +19,10 @@
 (custom-add-loads 'lisp '("func-menu"))
 (custom-add-loads 'applications '("uniquify"))
 (custom-add-loads 'outlines '("outl-mouse"))
-(custom-add-loads 'paren-matching '("paren"))
+(custom-add-loads 'paren-matching '("paren" "mic-paren"))
 (custom-add-loads 'avoid '("avoid"))
 (custom-add-loads 'help '("man"))
+(custom-add-loads 'mic-paren-matching '("mic-paren" "paren"))
 (custom-add-loads 'winring '("winring"))
 (custom-add-loads 'data '("saveplace"))
 (custom-add-loads 'backup '("backup-dir"))
@@ -47,7 +48,7 @@
 (custom-add-loads 'detached-minibuf '("detached-minibuf"))
 (custom-add-loads 'resize-minibuffer '("rsz-minibuf"))
 (custom-add-loads 'balloon-help '("balloon-help"))
-(custom-add-loads 'faces '("fast-lock" "lazy-shot"))
+(custom-add-loads 'faces '("fast-lock" "lazy-shot" "mic-paren"))
 (custom-add-loads 'pages '("page-ext"))
 (custom-add-loads 'savehist '("savehist"))
 (custom-add-loads 'editing '("bookmark" "permanent-buffers"))
